@@ -3,13 +3,13 @@ import sys
 import os
 import re
 import importlib
-from typing import List, Iterable, Union, Iterator
+from typing import List, Iterable, Optional, Union, Iterator
 from types import ModuleType
 from .jc_types import ParserInfoType, JSONDictType
 from jc import appdirs
 
 
-__version__ = '1.22.5'
+__version__ = '1.23.1'
 
 parsers: List[str] = [
     'acpi',
@@ -159,6 +159,7 @@ parsers: List[str] = [
     'sfdisk',
     'shadow',
     'ss',
+    'ssh-conf',
     'sshd-conf',
     'stat',
     'stat-s',
@@ -189,6 +190,7 @@ parsers: List[str] = [
     'upower',
     'uptime',
     'url',
+    'ver',
     'vmstat',
     'vmstat-s',
     'w',
@@ -198,7 +200,9 @@ parsers: List[str] = [
     'xml',
     'xrandr',
     'yaml',
-    'zipinfo'
+    'zipinfo',
+    'zpool-iostat',
+    'zpool-status'
 ]
 
 def _cliname_to_modname(parser_cli_name: str) -> str:
@@ -209,6 +213,19 @@ def _modname_to_cliname(parser_mod_name: str) -> str:
     """Return module's cli name (underscores converted to dashes)"""
     return parser_mod_name.replace('_', '-')
 
+def _is_valid_parser_plugin(name: str, local_parsers_dir: str) -> bool:
+    if re.match(r'\w+\.py$', name) and os.path.isfile(os.path.join(local_parsers_dir, name)):
+        try:
+            parser_mod_name = _cliname_to_modname(name)[0:-3]
+            modpath = 'jcparsers.'
+            plugin =  importlib.import_module(f'{modpath}{parser_mod_name}')
+            if hasattr(plugin, 'info') and hasattr(plugin, 'parse'):
+                del plugin
+                return True
+        except Exception:
+            return False
+    return False
+
 # Create the local_parsers list. This is a list of custom or
 # override parsers from <user_data_dir>/jc/jcparsers/*.py.
 # Once this list is created, extend the parsers list with it.
@@ -218,7 +235,7 @@ local_parsers_dir = os.path.join(data_dir, 'jcparsers')
 if os.path.isdir(local_parsers_dir):
     sys.path.append(data_dir)
     for name in os.listdir(local_parsers_dir):
-        if re.match(r'\w+\.py$', name) and os.path.isfile(os.path.join(local_parsers_dir, name)):
+        if _is_valid_parser_plugin(name, local_parsers_dir):
             plugin_name = name[0:-3]
             local_parsers.append(_modname_to_cliname(plugin_name))
             if plugin_name not in parsers:
@@ -279,7 +296,7 @@ def parse(
     data: Union[str, bytes, Iterable[str]],
     quiet: bool = False,
     raw: bool = False,
-    ignore_exceptions: bool = None,
+    ignore_exceptions: Optional[bool] = None,
     **kwargs
 ) -> Union[JSONDictType, List[JSONDictType], Iterator[JSONDictType]]:
     """
